cli

package
v0.0.0-...-3fe1002 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Title style - bold red with fire emoji
	TitleStyle = lipgloss.NewStyle().
				Bold(true).
				Foreground(primaryColor).
				MarginBottom(1)

	// Section header style
	HeaderStyle = lipgloss.NewStyle().
				Bold(true).
				Foreground(accentColor).
				MarginTop(1).
				MarginBottom(1)

	// Error message style
	ErrorStyle = lipgloss.NewStyle().
				Bold(true).
				Foreground(primaryColor)

	// Highlight style for important values
	HighlightStyle = lipgloss.NewStyle().
					Bold(true).
					Foreground(highlightColor)

	// Key-value pair styles
	KeyStyle = lipgloss.NewStyle().
				Foreground(mutedColor)

	ValueStyle = lipgloss.NewStyle().
				Bold(true).
				Foreground(textColor)
)

Styles

Functions

func PrintError

func PrintError(message string)

PrintError prints an error message

func PrintHardwareProbe

func PrintHardwareProbe(encoders []EncoderInfo)

PrintHardwareProbe prints a styled hardware encoder probe result

func PrintVersion

func PrintVersion(version string)

PrintVersion prints version information

func StyledHelpPrinter

func StyledHelpPrinter(options kong.HelpOptions) kong.HelpPrinter

StyledHelpPrinter creates a custom help printer with Lipgloss styling

Types

type EncoderInfo

type EncoderInfo struct {
	Name        string
	Description string
	Available   bool
}

EncoderInfo holds information about a hardware encoder for display

Jump to