Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Title style - bold red with fire emoji TitleStyle = lipgloss.NewStyle(). Bold(true). Foreground(primaryColor). MarginBottom(1) // Section header style HeaderStyle = lipgloss.NewStyle(). Bold(true). Foreground(accentColor). MarginTop(1). MarginBottom(1) // Error message style ErrorStyle = lipgloss.NewStyle(). Bold(true). Foreground(primaryColor) // Highlight style for important values HighlightStyle = lipgloss.NewStyle(). Bold(true). Foreground(highlightColor) // Key-value pair styles KeyStyle = lipgloss.NewStyle(). Foreground(mutedColor) ValueStyle = lipgloss.NewStyle(). Bold(true). Foreground(textColor) )
Styles
Functions ¶
func PrintHardwareProbe ¶
func PrintHardwareProbe(encoders []EncoderInfo)
PrintHardwareProbe prints a styled hardware encoder probe result
func StyledHelpPrinter ¶
func StyledHelpPrinter(options kong.HelpOptions) kong.HelpPrinter
StyledHelpPrinter creates a custom help printer with Lipgloss styling
Types ¶
type EncoderInfo ¶
EncoderInfo holds information about a hardware encoder for display
Click to show internal directories.
Click to hide internal directories.